@@ -153,20 +153,16 @@ class AddVisitor : public Visitor
 public:
     AddVisitor(T *r) : mResource(r) {}
 
-    bool visit(const Event::Ptr &e) Q_DECL_OVERRIDE
-    {
+    bool visit(const Event::Ptr &e) Q_DECL_OVERRIDE {
         return mResource->addEvent(e);
     }
-    bool visit(const Todo::Ptr &t) Q_DECL_OVERRIDE
-    {
+    bool visit(const Todo::Ptr &t) Q_DECL_OVERRIDE {
         return mResource->addTodo(t);
     }
-    bool visit(const Journal::Ptr &j) Q_DECL_OVERRIDE
-    {
+    bool visit(const Journal::Ptr &j) Q_DECL_OVERRIDE {
         return mResource->addJournal(j);
     }
-    bool visit(const FreeBusy::Ptr &) Q_DECL_OVERRIDE
-    {
+    bool visit(const FreeBusy::Ptr &) Q_DECL_OVERRIDE {
         return false;
     }
 
@@ -185,23 +181,19 @@ class DeleteVisitor : public Visitor
 public:
     DeleteVisitor(T *r) : mResource(r) {}
 
-    bool visit(const Event::Ptr &e) Q_DECL_OVERRIDE
-    {
+    bool visit(const Event::Ptr &e) Q_DECL_OVERRIDE {
         mResource->deleteEvent(e);
         return true;
     }
-    bool visit(const Todo::Ptr &t) Q_DECL_OVERRIDE
-    {
+    bool visit(const Todo::Ptr &t) Q_DECL_OVERRIDE {
         mResource->deleteTodo(t);
         return true;
     }
-    bool visit(const Journal::Ptr &j) Q_DECL_OVERRIDE
-    {
+    bool visit(const Journal::Ptr &j) Q_DECL_OVERRIDE {
         mResource->deleteJournal(j);
         return true;
     }
-    bool visit(const FreeBusy::Ptr &) Q_DECL_OVERRIDE
-    {
+    bool visit(const FreeBusy::Ptr &) Q_DECL_OVERRIDE {
         return false;
     }
 
@@ -1182,13 +1174,23 @@ void Calendar::CalendarObserver::calendarIncidenceChanged(const Incidence::Ptr &
     Q_UNUSED(incidence);
 }
 
+void Calendar::CalendarObserver::calendarIncidenceAboutToBeDeleted(const Incidence::Ptr &incidence)
+{
+    Q_UNUSED(incidence);
+}
+
 void Calendar::CalendarObserver::calendarIncidenceDeleted(const Incidence::Ptr &incidence)
 {
     Q_UNUSED(incidence);
 }
 
-void
-Calendar::CalendarObserver::calendarIncidenceAdditionCanceled(const Incidence::Ptr &incidence)
+void Calendar::CalendarObserver::calendarIncidenceDeleted(const Incidence::Ptr &incidence, const Calendar *calendar)
+{
+    Q_UNUSED(incidence);
+    Q_UNUSED(calendar);
+}
+
+void Calendar::CalendarObserver::calendarIncidenceAdditionCanceled(const Incidence::Ptr &incidence)
 {
     Q_UNUSED(incidence);
 }
@@ -1300,7 +1302,22 @@ void Calendar::notifyIncidenceChanged(const Incidence::Ptr &incidence)
     }
 }
 
-void Calendar::notifyIncidenceDeleted(const Incidence::Ptr &incidence)
+void Calendar::notifyIncidenceAboutToBeDeleted(const Incidence::Ptr &incidence)
+{
+    if (!incidence) {
+        return;
+    }
+
+    if (!d->mObserversEnabled) {
+        return;
+    }
+
+    foreach (CalendarObserver *observer, d->mObservers) {
+        observer->calendarIncidenceAboutToBeDeleted(incidence);
+    }
+}
+
+void Calendar::notifyIncidenceDeletedOld(const Incidence::Ptr &incidence)
 {
     if (!incidence) {
         return;
@@ -1315,6 +1332,21 @@ void Calendar::notifyIncidenceDeleted(const Incidence::Ptr &incidence)
     }
 }
 
+void Calendar::notifyIncidenceDeleted(const Incidence::Ptr &incidence)
+{
+    if (!incidence) {
+        return;
+    }
+
+    if (!d->mObserversEnabled) {
+        return;
+    }
+
+    foreach (CalendarObserver *observer, d->mObservers) {
+        observer->calendarIncidenceDeleted(incidence, this);
+    }
+}
+
 void Calendar::notifyIncidenceAdditionCanceled(const Incidence::Ptr &incidence)
 {
     if (!incidence) {
