@@ -152,9 +152,9 @@ Incidence::Ptr ICalFormat::readIncidence(const QByteArray &string, ICalTimeZones
     icalcomponent *calendar;
 
     // Let's defend const correctness until the very gates of hell^Wlibical
-    calendar = icalcomponent_new_from_string(const_cast<char*>((const char *)string));
+    calendar = icalcomponent_new_from_string(const_cast<char *>(string.constData()));
     if (!calendar) {
-        qCritical() << "parse error ; string is empty?" << string.isEmpty();
+        qCritical() << "parse error from icalcomponent_new_from_string. string=" << QString::fromLatin1(string);
         setException(new Exception(Exception::ParseErrorIcal));
         return Incidence::Ptr();
     }
@@ -189,9 +189,9 @@ bool ICalFormat::fromRawString(const Calendar::Ptr &cal, const QByteArray &strin
     icalcomponent *calendar;
 
     // Let's defend const correctness until the very gates of hell^Wlibical
-    calendar = icalcomponent_new_from_string(const_cast<char *>((const char *)string));
+    calendar = icalcomponent_new_from_string(const_cast<char *>(string.constData()));
     if (!calendar) {
-        qCritical() << "parse error ; string is empty?" << string.isEmpty();
+        qCritical() << "parse error from icalcomponent_new_from_string. string=" << QString::fromLatin1(string);
         setException(new Exception(Exception::ParseErrorIcal));
         return false;
     }
